@@ -175,7 +175,7 @@ pub fn solve(input: &mut Input) -> Result<i128, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let example = "939\n7,13,x,x,59,x,31,19";
     test_part_one!(example => 295);
